==> haskell-cmark-0.5.6-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark
version: 0.5.6
id: cmark-0.5.6-EsjzmWfoyko59GqsfxKW0P
key: cmark-0.5.6-EsjzmWfoyko59GqsfxKW0P
license: BSD3
copyright: (C) 2015--17 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/cmark-hs
synopsis: Fast, accurate CommonMark (Markdown) parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/jgm/cmark libcmark>, the reference
    parser for <http://commonmark.org CommonMark>, a fully
    specified variant of Markdown. It includes sources for
    libcmark (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    CMark
abi: ba00a58389bfaa4c2340dff5097201ec
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cmark-0.5.6
hs-libraries: HScmark-0.5.6-EsjzmWfoyko59GqsfxKW0P
extra-libraries:
    cmark
depends:
    base-4.10.1.0 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
haddock-html: /usr/share/doc/haskell-cmark/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-0.5.6-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmark.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmark
version: 0.5.6
id: cmark-0.5.6-GOxMLW6CNvDGdoQGpA4CIP
key: cmark-0.5.6-GOxMLW6CNvDGdoQGpA4CIP
license: BSD3
copyright: (C) 2015--17 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/cmark-hs
synopsis: Fast, accurate CommonMark (Markdown) parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/jgm/cmark libcmark>, the reference
    parser for <http://commonmark.org CommonMark>, a fully
    specified variant of Markdown. It includes sources for
    libcmark (0.28.0) and does not require prior installation of the
    C library.
category: Text
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    CMark
abi: 0403c02008b9242f8a012647f682fbfb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/cmark-0.5.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cmark-0.5.6
hs-libraries: HScmark-0.5.6-GOxMLW6CNvDGdoQGpA4CIP
extra-libraries:
    cmark
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
haddock-html: /usr/share/doc/haskell-cmark/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
